@@ -4,6 +4,7 @@ build our python3 and python2 recipes and his corresponding hostpython recipes.
 '''
 
 from os.path import dirname, exists, join
+from multiprocessing import cpu_count
 from shutil import copy2
 from os import environ
 import subprocess
@@ -48,13 +49,9 @@ class GuestPythonRecipe(TargetPythonRecipe):
         this limitation.
     '''
 
-    from_crystax = False
-    '''True if the python is used from CrystaX, False otherwise (i.e. if
-    it is built by p4a).'''
-
     configure_args = ()
     '''The configure arguments needed to build the python recipe. Those are
-    used in method :meth:`build_arch` (if not overwritten like python3crystax's
+    used in method :meth:`build_arch` (if not overwritten like python3's
     recipe does).
 
     .. note:: This variable should be properly set in subclass.
@@ -107,10 +104,6 @@ class GuestPythonRecipe(TargetPythonRecipe):
         super(GuestPythonRecipe, self).__init__(*args, **kwargs)
 
     def get_recipe_env(self, arch=None, with_flags_in_cc=True):
-        if self.from_crystax:
-            return super(GuestPythonRecipe, self).get_recipe_env(
-                arch=arch, with_flags_in_cc=with_flags_in_cc)
-
         env = environ.copy()
 
         android_host = env['HOSTARCH'] = arch.command_prefix
@@ -169,6 +162,14 @@ class GuestPythonRecipe(TargetPythonRecipe):
 
         env['SYSROOT'] = sysroot
 
+        if sh.which('lld') is not None:
+            # Note: The -L. is to fix a bug in python 3.7.
+            # https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=234409
+            env["LDFLAGS"] += ' -L. -fuse-ld=lld'
+        else:
+            logger.warning('lld not found, linking without it. ' +
+                           'Consider installing lld if linker errors occur.')
+
         return env
 
     def set_libs_flags(self, env, arch):
@@ -206,10 +207,6 @@ class GuestPythonRecipe(TargetPythonRecipe):
 
     def prebuild_arch(self, arch):
         super(TargetPythonRecipe, self).prebuild_arch(arch)
-        if self.from_crystax and self.ctx.ndk != 'crystax':
-            raise BuildInterruptingException(
-                'The {} recipe can only be built when using the CrystaX NDK. '
-                'Exiting.'.format(self.name))
         self.ctx.python_recipe = self
 
     def build_arch(self, arch):
@@ -250,7 +247,7 @@ class GuestPythonRecipe(TargetPythonRecipe):
                 py_version = self.major_minor_version_string
                 if self.major_minor_version_string[0] == '3':
                     py_version += 'm'
-                shprint(sh.make, 'all',
+                shprint(sh.make, 'all', '-j', str(cpu_count()),
                         'INSTSONAME=libpython{version}.so'.format(
                             version=py_version), _env=env)
 
@@ -420,7 +417,7 @@ class HostPythonRecipe(Recipe):
                 shprint(sh.cp, join('Modules', 'Setup.dist'),
                         join(build_dir, 'Modules', 'Setup'))
 
-                result = shprint(sh.make, '-C', build_dir)
+                shprint(sh.make, '-j', str(cpu_count()), '-C', build_dir)
         else:
             info('Skipping {name} ({version}) build, as it has already '
                  'been completed'.format(name=self.name, version=self.version))
